#!/usr/bin/env bash

set -e
set -x

# Directory where navigator server and scale test tgz have been extracted
NAV_HOME=$1
NAV_SCALE_DIR=${NAV_HOME}/cloudera-navigator-scale-test
NAV_SERVER_DIR=${NAV_HOME}/cloudera-navigator-server

NAV_SCALE_JAR_FILENAME=nav-scale-2.1.0-SNAPSHOT.jar
SCALA_COMPILER_JAR=scala-compiler-2.10.0.jar
SCALA_LIBRARY_JAR=scala-library-2.10.4.jar

# NOTE: this function is copied from cloudera-config.sh (but cannot be sourced here)
get_java_major_version() {
  if [ -z $JAVA_HOME/bin/java ]; then
    echo "JAVA_HOME must be set"
    exit 1
  fi
  local VERSION_STRING=`$JAVA_HOME/bin/java -version 2>&1`
  local RE_JAVA='[java|openjdk][[:space:]]version[[:space:]]\"1\.([0-9][0-9]*)\.?+'
  if [[ $VERSION_STRING =~ $RE_JAVA  ]]; then
    eval $1=${BASH_REMATCH[1]}
  else
    RE_JAVA='[java|openjdk][[:space:]]version[[:space:]]\"([0-9][0-9]*)\.?+'
    if [[ $VERSION_STRING =~ $RE_JAVA  ]]; then
      eval $1=${BASH_REMATCH[1]}
    fi
  fi
}

# get GC args based on java version
get_java_gc_opts_based_on_java_version() {
  get_java_major_version JAVA_MAJOR
  BASIC_GC_TUNING_ARGS=""
  # placeholder for GC args
  case $JAVA_MAJOR in
    8)   BASIC_GC_TUNING_ARGS="-XX:+UseConcMarkSweepGC -XX:-CMSConcurrentMTEnabled -XX:+UseParNewGC"
         ;;
    11)  BASIC_GC_TUNING_ARGS=""
         ;;
    *)   echo "Unable to detect JAVA version. Skip using GC tuning args"
         ;;
    eval "$1=\$BASIC_GC_TUNING_ARGS"
  esac
}


# Add nav-scale and scala jars to the war file. These files
# need to live in WEB-INF/lib directory
mkdir -p /tmp/WEB-INF/lib
cp -f ${NAV_SCALE_DIR}/jars/${NAV_SCALE_JAR_FILENAME} /tmp/WEB-INF/lib
cp -f ${NAV_SCALE_DIR}/jars/${SCALA_COMPILER_JAR} /tmp/WEB-INF/lib
cp -f ${NAV_SCALE_DIR}/jars/${SCALA_LIBRARY_JAR} /tmp/WEB-INF/lib
jar uf ${NAV_SERVER_DIR}/wars/nav-service-2.1.0-SNAPSHOT.war -C /tmp WEB-INF/lib/${NAV_SCALE_JAR_FILENAME}
jar uf ${NAV_SERVER_DIR}/wars/nav-service-2.1.0-SNAPSHOT.war -C /tmp WEB-INF/lib/${SCALA_COMPILER_JAR}
jar uf ${NAV_SERVER_DIR}/wars/nav-service-2.1.0-SNAPSHOT.war -C /tmp WEB-INF/lib/${SCALA_LIBRARY_JAR}
rm -rf /tmp/WEB-INF

# Substitute environemt variables in nav.properties
sed -i "s#{NAV_SCALE_DIR}#${NAV_HOME}#g" ${NAV_SCALE_DIR}/conf/nav.properties

# fetch GC args based on java version
get_java_gc_opts_based_on_java_version NAV_GC_ARGS

exec java -server ${NAV_GC_ARGS} -XX:MaxPermSize=128M -Xmx6g -Djava.awt.headless=true -Dnav.home=${NAV_SERVER_DIR} -Dnav.test.cdh4.nn.image_file=${NAV_HOME}/hdfs/fsimage -cp "${NAV_SERVER_DIR}/nav-server.jar:${NAV_SERVER_DIR}/jars/*" com.cloudera.nav.server.NavServer ${NAV_SCALE_DIR}/conf/nav.properties
